========
cbmshell
========

A Python application to manipulate the contents of disk and tape
images used by emulators of Commodore 8-bit microcomputers.

Files can be copied between an image and the local filesystem as well
as converted to and from PETSCII.

``cbmshell`` has many of the properties of a UNIX shell, giving both
an interactive environment and the ability to run predefined scripts.


Getting Started
===============

.. include:: overview/summary.rst


Topics
========

.. toctree::
   :maxdepth: 2

   topics/index


Examples
========

.. toctree::
   :maxdepth: 2

   examples/index
